# Result

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**resource_type** | **str** |  | [optional] 
**resource_name** | **str** |  | [optional] 
**score** | **float** |  | [optional] 
**billing_account** | [**BillingAccountResult**](BillingAccountResult.md) |  | [optional] 
**project** | [**ProjectResult**](ProjectResult.md) |  | [optional] 
**virtual_machine** | [**VirtualMachineResult**](VirtualMachineResult.md) |  | [optional] 
**disk** | [**DiskResult**](DiskResult.md) |  | [optional] 
**image** | [**ImageResult**](ImageResult.md) |  | [optional] 
**network** | [**NetworkResult**](NetworkResult.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


